#!/bin/bash
#
# Unzip and transcode to ogg

set -e

until [ -z "$1" ]
do
ZIPNAME="$1"
shift
VGMSTREAM="/home/agashlin/Desktop/vgmstream/test/test"

if ! [ -e "$ZIPNAME" ] ; then
    echo "missing zip"
    exit
fi

if ! echo "$ZIPNAME" | grep ".zip" > /dev/null ; then
    echo "not .zip"
    exit
fi
ZIPNAMEBASE="$(basename "$ZIPNAME" .zip)"

mkdir "$ZIPNAMEBASE"
cd "$ZIPNAMEBASE"
zipinfo -1 "$ZIPNAME" | while read FILENAME ; do
    FILENAMEDIR="$(dirname "$FILENAME")"
    FILENAMEBASE="$(basename "$FILENAME")"
    FILENAMENOEXT="$(echo "$FILENAME" | sed -e "s/[.][^.]*\$//")"
    FILENAMEEXT="$(echo "$FILENAME" | sed -e "s/^.*[.]\([^.]*\)\$/\\1/")"
    FILENAMEESCAPED="$(echo "$FILENAME" | sed -e "s/\\[/[[]/g" -e "s/\\?/[?]/g" -e "s/\\*/[*]/g")"

    if [ "$FILENAMEDIR" != "" ] ; then mkdir -p "$FILENAMEDIR" ; fi

    case "$FILENAMEEXT" in
    flac)
        unzip -p "$ZIPNAME" "$FILENAMEESCAPED" | flac -d -o - - | oggenc -q 5 -o "$FILENAMENOEXT.ogg" -
        ;;
    wav)
        unzip -p "$ZIPNAME" "$FILENAMEESCAPED" | oggenc -q 5 -o "$FILENAMENOEXT.ogg" -
        ;;
    ogg)
        unzip -p "$ZIPNAME" "$FILENAMEESCAPED" > "$FILENAMENOEXT.ogg"
        ;;
    *)
        TEMPFILE="$(tempfile --suffix "$FILENAMEBASE")"
        unzip -p "$ZIPNAME" "$FILENAMEESCAPED" > "$TEMPFILE"
        if [ -x "$VGMSTREAM" ] ; then
            if "$VGMSTREAM" -m "$TEMPFILE" ; then
                "$VGMSTREAM" -p "$TEMPFILE" | oggenc -q 5 -o "$FILENAMENOEXT.ogg" -
            else
                echo "skipping $FILENAME"
            fi
        else
            echo "missing vgmstream for $FILENAME"
        fi
        rm "$TEMPFILE"
        ;;
    esac
done
cd ..
done
